@@ -29,8 +29,9 @@ def parseArgv():
         logger.info(f' a: {a}')
     mysim = simulation.simulation_params()
     mysim.setFastaFile(args.fasta)
-    mysim.setSigma(args.sigma)
-    mysim.seta(args.a)
+    # Use default values if not provided
+    mysim.setSigma(args.sigma if args.sigma is not None else 0.07)
+    mysim.seta(args.a if args.a is not None else 10)
 
     return(mysim)
 
@@ -40,7 +41,8 @@ def main():
     myres = simulation.simulation_main(mysim)
     print(myres)
 
-main()
+if __name__ == "__main__":
+    main()
 
 
 
